@@ -28,5 +28,20 @@ function (method)
             return(randomForest(Z, T))
         }
     }
+    else if (method == "glmnet") {
+        rval = function(Z, T) {
+            return(cv.glmnet(Z, T, family = "multinomial"))
+        }
+    }
+    else if (method == "glmnet2") {
+        rval = function(Z, T) {
+            means = apply(Z, 2, mean)
+            sds = apply(Z, 2, sd)
+            Z = scale(Z)
+            Z = as.matrix(model.matrix(~.^2, data = data.frame(Z))[, 
+                -1])
+            return(list(means, sds, cv.glmnet(Z, T, family = "multinomial")))
+        }
+    }
     return(rval)
 }
